// ----------------------------------------------------------------------------
// Words.java
// separating the words of a text
// 
// Author:  Wolfgang Schreiner <Wolfgang.Schreiner@fhs-hagenberg.ac.at>
// Created: August 25, 2001
// ----------------------------------------------------------------------------
public class Words
{
  // --------------------------------------------------------------------------
  // * reads from standard input stream a string which contains words
  // (sequences of letters) separated by other characters.
  // * prints to standard output stream all words of the text in separate lines
  // in their order of occurrence in the text.
  // --------------------------------------------------------------------------
  public static void main(String[] args)
  {
    String text = Input.readString();
    printWords(text);
  }

  // --------------------------------------------------------------------------
  // printWords(text)
  // print the words of 'text'.
  //
  // Input condition:
  //   'text' is not null.
  // Effect:
  //   Prints to standard output stream all words of 'text' in separate lines
  //   in their order of occurrence in 'text'.
  // --------------------------------------------------------------------------
  public static void printWords(String text)
  {
    int i = 0;
    final int end = text.length();
    while (i < end)
    {
      int a = wordBegin(text, i);
      assert a == end || Character.isLetter(text.charAt(a));
      if (a == end) break;
      int b = wordEnd(text, a);
      assert b == end || !Character.isLetter(text.charAt(b));
      System.out.println(text.substring(a, b));
      i = b+1;
    }
  }

  // --------------------------------------------------------------------------
  // a = wordBegin(text, i)
  // a is the position of the first word of 'text' at or after position 'i'
  //
  // Input condition:
  //   'text' is not null.
  //   'text'.length() > i
  // Output condition:
  //   * 'i <= a <= end'
  //   * if 'a = end', then 'text' does not have a word at or after 'i'.
  //   * if 'a < end', then 'a' denotes the start of the first word
  //     at or after 'i'.
  // --------------------------------------------------------------------------
  static int wordBegin(String text, int i)
  {
    int a = i;
    final int end = text.length();
    while (a < end && !Character.isLetter(text.charAt(a)))
      a = a+1;
    return a;
  }

  // --------------------------------------------------------------------------
  // b = wordEnd(text, a)
  // 'b' is the position of the first character after the word beginning
  // in 'text' at position 'a'
  //
  // Input condition:
  ///  'text' is not null and 'a' < 'text'.length().
  //   'text' starts a word at position 'a'.
  //
  // Output condition:
  //   * 'a < b <= end'
  //   * if 'b = end', then word ranges from 'a' to end of text.
  //   * if 'b < end', then 'b' denotes the first character after the
  //     word starting at 'a'.
  // --------------------------------------------------------------------------
  static int wordEnd(String text, int a)
  {
    int b = a+1;
    final int end = text.length();
    while (b < end && Character.isLetter(text.charAt(b)))   
      b = b+1;
    return b;
  }
}
